@@ -44,6 +44,15 @@ def configuration(config_user_ini = 'config_user.ini', config_project_ini='confi
     config_files = [f for f in [config_project_ini, config_user_ini] if os.path.isfile(f)]
     CONFIG.read(config_files)
 
+    #Remove quotes form paths if people are confused
+    def strip_quotes_config(k1, k2, conf):
+        if k1 in conf and k2 in conf[k1]:
+            conf[k1][k2] = conf[k1][k2].strip('"').strip("'")
+
+    strip_quotes_config('Programs', 'stata_exe', CONFIG)
+    strip_quotes_config('SCons', 'success_batch_log_dir', CONFIG)
+    strip_quotes_config('Project', 'cache_dir', CONFIG)
+    
     return CONFIG
 
 AddOption(
@@ -127,12 +136,53 @@ AddOption(
     type="string",
     help='assume built',
 )
+AddOption(
+    '--assume-done',
+    dest='assume_done',
+    action='store',
+    type="string",
+    help='assume done',
+)
 
+
+# Deciders
+# Note that timestamp-newer/make compares target vs source, whereas timestamp-changed doesn't look at target (just prev vs current of source)
+# 'content-timestamp' = 'timestamp-changed' and 'content'
+
+# 'make' and 'content'
+def dependency_newer_then_content_changed(dependency, target, prev_ni, repo_node=None):
+    return dependency.changed_timestamp_newer(target, prev_ni, repo_node) and dependency.changed_content(target, prev_ni, repo_node)
+
+# 'make' and 'content-timestamp'
+def changed_timestamp_then_dependency_newer_then_content_content(dependency, target, prev_ni, repo_node=None):
+    return dependency.changed_timestamp_newer(target, prev_ni, repo_node) and dependency.changed_timestamp_then_content(target, prev_ni, repo_node)
+
+decider_str_lookup = {'content-timestamp-newer': dependency_newer_then_content_changed,
+                      'content-timestamp-newer-timestamp-changed': changed_timestamp_then_dependency_newer_then_content_content}
+decider_str_lookup.update({k:k for k in ['MD5', 'content', 'MD5-timestamp', 'content-timestamp', 'timestamp-newer', 'make', 'timestamp-match']})
+
+
+#We impliment these skip-logic routines in stata_run() and not a dedicated Decider so that
+# someone can change them on the command-line without changing any files and is orthogonal
+# to what decider they choose (MD5, MD5-timestamp)
 assume_built = GetOption('assume_built') #If there are outer quotes on the cli, these are stripped.
 assume_built_list = []
 if not assume_built is None:
     assume_built_list = [str(path) for file_pattern in assume_built.split(':') for path in Path().rglob(file_pattern) if not path.is_dir()] #could've used os.pathsep, but want consistent across sytems
 
+assume_done = GetOption('assume_done') #If there are outer quotes on the cli, these are stripped.
+assume_done_list = []
+if not assume_done is None:
+    assume_done_list = [str(path) for file_pattern in assume_done.split(':') for path in Path().rglob(file_pattern) if not path.is_dir()] #could've used os.pathsep, but want consistent across sytems
+
+#AddOption(
+#    '--skip-newer',
+#    dest='skip_newer',
+#    action='store_true',
+#    default=False,
+#    help='skip newer',
+#)
+
 # Can't use the Builder chdir option, since that moves the target dir (and we want source)
 stata_chdir = config['SCons']['stata_chdir']
 if stata_chdir=='': stata_chdir = 0
@@ -144,14 +194,24 @@ def stata_run(target, source, env, params="", file_cmd="do", full_cmd=None):
         fname = str(source[0]) #Assumes the first element of source is the do file
         
     assume_built = GetOption('assume_built')
-    
-    if not assume_built is None:
-        if ('fname' in locals() and fname in assume_built_list) or all([str(t) in assume_built_list for t in target]):
-            for t in target: Path(str(t)).touch() #In case someone is using a time-stamp option for content being up-to-date. Touch() doesn't seem to work
-            if full_cmd is None: full_cmd = file_cmd + ' "' + fname + '" ' + params
-            if not GetOption('silent'):
-                SCons.Debug.Trace("Assuming built: " + full_cmd + "\n", pre_sys_stdout)
-            return 0
+    if not assume_built is None and all([str(t) in assume_built_list for t in target]):
+        if full_cmd is None: full_cmd = file_cmd + ' "' + fname + '" ' + params
+        for t in target: Path(str(t)).touch() #In case someone is using a time-stamp option for content being up-to-date. Touch() doesn't seem to work
+        if not GetOption('silent'):
+            SCons.Debug.Trace("Assuming built: " + full_cmd + "\n", pre_sys_stdout)
+        return 0
+    assume_done = GetOption('assume_done')
+    if not assume_done is None and 'fname' in locals() and fname in assume_done_list:
+        for t in target: Path(str(t)).touch() #In case someone is using a time-stamp option for content being up-to-date. Touch() doesn't seem to work
+        if not GetOption('silent'):
+            SCons.Debug.Trace("Assuming done: " + fname + "\n", pre_sys_stdout)
+        return 0
+
+    #if GetOption('skip_newer') and min([os.path.getmtime(str(t)) for t in target]) > max([os.path.getmtime(str(s)) for s in source]):
+    #    if not GetOption('silent'):
+    #        if full_cmd is None: full_cmd = file_cmd + ' "' + fname + '" ' + params
+    #        SCons.Debug.Trace("Skipping newer: " + full_cmd + "\n", pre_sys_stdout)
+    #    return 0
 
     cwd = None
     if stata_chdir == 1 and full_cmd is None:
